@@ -1,6 +1,8 @@
 import logging
 from collections.abc import Generator
 
+from pmaw.Cache import Cache
+
 log = logging.getLogger(__name__)
 
 
@@ -15,6 +17,20 @@ class Response(Generator):
         # indexing for returning responses
         self.i = 0
         self.num_cache = 0
+    
+    @staticmethod
+    def load_cache(key, cache_dir=None):
+        """
+        Return an instance of Response with the results stored with the provided key
+
+        Input:
+            key (str) - Cache key for results to load into Response
+            cache_dir (str, optional) - An absolute or relative folder path to load cached responses from, defaults to './cache'
+        Output:
+            Response generator object
+        """
+        cache = Cache.load_with_key(key, cache_dir)
+        return Response(cache)
 
     def to_cache(self):
         self._cache.cache_responses(self.responses)
